SimpleSelfRebuff:_rev("$Revision: 44957 $")

-------------------------------------------------------------------------------
-- Externals
-------------------------------------------------------------------------------

local SimpleSelfRebuff = SimpleSelfRebuff
local L = AceLibrary("AceLocale-2.2"):new("SimpleSelfRebuff")

local STATE_UNSET   = SimpleSelfRebuff.STATE_UNSET
local STATE_BUFFED  = SimpleSelfRebuff.STATE_BUFFED
local STATE_FADING  = SimpleSelfRebuff.STATE_FADING
local STATE_MISSING = SimpleSelfRebuff.STATE_MISSING

-------------------------------------------------------------------------------
-- Locals
-------------------------------------------------------------------------------

local bindingButton
local TEH_BUTTON_NAME = "SimpleSelfRebuff_MouseWheelBindingButton"

local pendingBuff
local boundBuff

local updateEvents = {
	'SimpleSelfRebuff_MonitoringEnabled',
	'SimpleSelfRebuff_StateChanged',
	'PLAYER_REGEN_ENABLED',
	'SPELL_UPDATE_COOLDOWN',
	'BAG_UPDATE_COOLDOWN',
	'PLAYER_AURAS_CHANGED'
}

-------------------------------------------------------------------------------
-- Module declaration
-------------------------------------------------------------------------------

local MouseWheelBinding = SimpleSelfRebuff:NewModule('MouseWheelBinding')

MouseWheelBinding.optionName = L["Mouse wheel bindings"]

function MouseWheelBinding:OnModuleEnable()
	self:RegisterBucketEvent(updateEvents, 0.5, 'UpdateBinding')
	
	self:RegisterEvent('PLAYER_REGEN_DISABLED', 'SetBinding', false)
	self:RegisterEvent('SimpleSelfRebuff_MonitoringDisabled', 'SetBinding', false)
		
	self:UpdateBinding()
end

function MouseWheelBinding:OnModuleDisable()
	self:SetBinding(false)
end

function MouseWheelBinding:UpdateBinding()
	if self.core:IsMonitoringActive() then
		pendingBuff = self.core:GetPendingBuff(pendingBuff)	
		self:SetBinding(pendingBuff)		
	else
		self:SetBinding(false)
	end
end

function MouseWheelBinding:SetBinding(buff)

	if buff then
		
		if InCombatLockdown() or buff == boundBuff then
			return
		end

		self.core:Debug('Binding mousewheel')
		
		if not bindingButton then
			bindingButton = CreateFrame("Button", TEH_BUTTON_NAME, UIParent, "SecureActionButtonTemplate")
			bindingButton:RegisterForClicks("LeftButtonUp")
			bindingButton:SetPoint("CENTER",0,0)
			bindingButton:Hide()
		end
		
		-- Reset attributes
		bindingButton:SetAttribute('type', nil)
		bindingButton:SetAttribute('spell', nil)			
		bindingButton:SetAttribute('unit', nil)			
		bindingButton:SetAttribute('target-slot', nil)			
		
		-- Setup attributes depending on source and target
		buff:SetupSecureButton(bindingButton)
		
		-- Binding
		SetOverrideBindingClick(bindingButton, true, "MOUSEWHEELUP", TEH_BUTTON_NAME, "LeftButton")
		SetOverrideBindingClick(bindingButton, true, "MOUSEWHEELDOWN", TEH_BUTTON_NAME, "LeftButton")	
		
		boundBuff = buff
		
	elseif boundBuff then
		
		if InCombatLockdown() then
			self:ScheduleLeaveCombatAction('SetBinding', false)
		else		
			self.core:Debug('Unbinding mousewheel')
			ClearOverrideBindings(bindingButton)
			boundBuff = nil
		end
		
	end

end
